package de.bsvrz.sys.usv.wrapper;

import junit.framework.TestCase;

import org.junit.Test;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.ClientDavParameters;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.sys.usv.enums.BatterieZustand;
import de.bsvrz.sys.usv.enums.EingangsfrequenzZustand;
import de.bsvrz.sys.usv.enums.KommunikationsZustand;
import de.bsvrz.sys.usv.enums.USVZustand;
import de.bsvrz.sys.usv.enums.WechselSpannung;
import de.bsvrz.sys.usv.enums.ZustandNotstrom;
import de.bsvrz.sys.usv.enums.ZustandPhase;

/**
 * Test fr unseren {@link SchwellwertParser}.
 * 
 * @author BitCtrl Systems GmbH, Christian Hsel
 * @version $Id$
 */
public class SchwellwertParserTest extends TestCase {

	private ClientDavInterface con;

	/*
	 * (non-Javadoc)
	 * 
	 * @see junit.framework.TestCase#setUp()
	 */
	@Override
	protected void setUp() throws Exception {
		super.setUp();

		final ClientDavParameters parameter = new ClientDavParameters();
		parameter.setApplicationName("JUNIT Test");
		parameter.setDavCommunicationAddress(System.getProperty(
				"datenverteiler", "localhost"));
		parameter.setDavCommunicationSubAddress(Integer.parseInt(System
				.getProperty("davport", "8083")));
		parameter.setUserName(System.getProperty("benutzer", "Tester"));
		parameter.setUserPassword(System.getProperty("passwort", "geheim"));
		parameter.setSimulationVariant((short) 0);

		System.out.println("Verwende folgende Verbindungsparameter: \n"
				+ "\tdatenverteiler=" + parameter.getDavCommunicationAddress()
				+ "\n\tdavport=" + parameter.getDavCommunicationSubAddress()
				+ "\n\tbenutzer=" + parameter.getUserName() + "\n\tpasswort="
				+ parameter.getUserPassword());
		con = new ClientDavConnection(parameter);
		con.connect();
		con.login();

	}

	/**
	 * Erzeugt einen Default-Datensatz mit berall na.
	 * 
	 * @return
	 */
	private Data createDefaultData() {
		final AttributeGroup atg_usvZustand = con.getDataModel()
				.getAttributeGroup(UsvKonstanten.atg_usvZustand);

		final Data result = con.createData(atg_usvZustand);

		result.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		result.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		result.getScaledValue(UsvKonstanten.kommunikationsZustand).setText(
				KommunikationsZustand.na.getText());
		result.getScaledValue(UsvKonstanten.eingangsFrequenzZustand).setText(
				EingangsfrequenzZustand.na.getText());
		result.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.na.getText());
		result.getScaledValue(UsvKonstanten.zustandPhase1).setText(
				ZustandPhase.na.getText());
		result.getScaledValue(UsvKonstanten.zustandPhase2).setText(
				ZustandPhase.na.getText());
		result.getScaledValue(UsvKonstanten.zustandPhase3).setText(
				ZustandPhase.na.getText());
		result.getScaledValue(UsvKonstanten.zustandNotStrom).setText(
				ZustandNotstrom.na.getText());
		return result;
	}

	/**
	 * Test der Methode {@link SchwellwertParser#auswertung(String, Data)} mit
	 * einer ganzen Reihe von Schwellwertbedingungen.
	 */
	@Test
	public void testAuswertung() {

		/**
		 * "UsvZustand:gleich:Batteriebetrieb"
		 */
		Data data = createDefaultData();
		String schwellwertBedingung = "UsvZustand:gleich:Batteriebetrieb";
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		/**
		 * "UsvZustand:groesser:Batteriebetrieb"
		 */
		data = createDefaultData();
		schwellwertBedingung = "UsvZustand:groesser:Batteriebetrieb";
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		/**
		 * "UsvZustand:kleiner:Batteriebetrieb"
		 */
		data = createDefaultData();
		schwellwertBedingung = "UsvZustand:kleiner:Batteriebetrieb";
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		/**
		 * "BatterieZustand:gleich:40"
		 */
		data = createDefaultData();
		schwellwertBedingung = "BatterieZustand:gleich:40";

		data.getScaledValue(UsvKonstanten.batterieZustand).set(100);
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(40);
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(0);
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		/**
		 * "BatterieZustand:kleiner:40"
		 */
		data = createDefaultData();
		schwellwertBedingung = "BatterieZustand:kleiner:40";

		data.getScaledValue(UsvKonstanten.batterieZustand).set(100);
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(40);
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(0);
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		/**
		 * "BatterieZustand:groesser:40"
		 */
		data = createDefaultData();
		schwellwertBedingung = "BatterieZustand:groesser:40";

		data.getScaledValue(UsvKonstanten.batterieZustand).set(100);
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(40);
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(0);
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		/**
		 * "BatterieZustand:gleich:nicht ermittelbar"
		 */
		data = createDefaultData();
		schwellwertBedingung = "BatterieZustand:gleich:nicht ermittelbar";

		data.getScaledValue(UsvKonstanten.batterieZustand).set(100);
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(40);
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(0);
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		/**
		 * BatterieZustand:kleiner:40&UsvZustand:gleich:Batteriebetrieb
		 */
		data = createDefaultData();
		schwellwertBedingung = "BatterieZustand:kleiner:40&UsvZustand:gleich:Batteriebetrieb";

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(100);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(100);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(100);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(40);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(40);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(40);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(0);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(0);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(0);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		/**
		 * BatterieZustand:kleiner:40|UsvZustand:gleich:Batteriebetrieb
		 */
		data = createDefaultData();
		schwellwertBedingung = "BatterieZustand:kleiner:40|UsvZustand:gleich:Batteriebetrieb";

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(100);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(100);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(100);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(40);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(40);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(40);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(0);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(0);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.normal.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(0);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		/**
		 * XXX: Hier ist dann vor allem die Prioritt der Verknpfungen wichtig. | < & <
		 * kleiner = gleich = groesser
		 * 
		 * BatterieZustand:kleiner:40|UsvZustand:gleich:Batteriebetrieb&WechselSpannung:gleich:Unterspannung
		 */
		data = createDefaultData();
		schwellwertBedingung = "BatterieZustand:kleiner:40|UsvZustand:gleich:Batteriebetrieb&WechselSpannung:gleich:Unterspannung";

		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		data.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		data.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.Ueberspannung.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		data.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.Ueberspannung.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		data.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.Unterspannung.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(40);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		data.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.Unterspannung.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		data.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.normal.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		/**
		 * XXX: Hier ist dann vor allem die Prioritt der Verknpfungen wichtig. | < & <
		 * kleiner = gleich = groesser
		 * 
		 * XXX: Klammern beachten!!!
		 * 
		 * (BatterieZustand:kleiner:40|UsvZustand:gleich:Batteriebetrieb)&WechselSpannung:gleich:Unterspannung
		 */
		data = createDefaultData();
		schwellwertBedingung = "(BatterieZustand:kleiner:40|UsvZustand:gleich:Batteriebetrieb)&WechselSpannung:gleich:Unterspannung";

		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		data.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		data.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.Ueberspannung.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).setText(
				BatterieZustand.na.getText());
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		data.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.Ueberspannung.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.na.getText());
		data.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.Unterspannung.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(40);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		data.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.Unterspannung.getText());
		assertEquals(true, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

		data.getScaledValue(UsvKonstanten.batterieZustand).set(39);
		data.getScaledValue(UsvKonstanten.usvZustand).setText(
				USVZustand.Batterie.getText());
		data.getScaledValue(UsvKonstanten.wechselSpannung).setText(
				WechselSpannung.normal.getText());
		assertEquals(false, SchwellwertParser.auswertung(schwellwertBedingung,
				data));

	}

}
